unit FlatButton;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TButtonState = (stUp, stDown);
  TFlatButton = class(TGraphicControl)
  private
    FRandFarbe: TColor;
    FFarbe: TColor;
    FText: string;
    FButtonState: TButtonstate;
    FTextLeft: integer;
    FTextTop: integer;
    procedure SetRandFarbe(RF: TColor);
    procedure SetFarbe(FB: TColor);
    procedure SetTextLeft(TL: integer);
    procedure SetTextTop(TT: integer);
    procedure SetText(T: string);
    procedure PaintUp;
    procedure PaintDown;
    procedure SetButtonState(BS: TButtonState);
  protected

  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure MouseDown(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
    procedure paint; override;

  published
    property Randfarbe: TColor read FRandFarbe write SetRandFarbe;
    property Farbe: TColor read FFarbe write SetFarbe;
    property TextLeft: integer read FTextLeft write SetTextLeft;
    property TextTop: integer read FTextTop write SetTextTop;
    property Caption: string read FText write SetText;
    property ButtonState: TButtonState read FButtonState write SetButtonState;
    property Font;
    property OnMouseDown;
    property OnMouseUp;
    property OnClick;
  end;

procedure Register;

implementation

var
 h, w, a, zz, o, x, y, l: integer;

//====================================================================================================

procedure TFlatButton.SetRandFarbe(RF: TColor);
begin
 FRandFarbe := RF;
 paint;
end;

//====================================================================================================

procedure TFlatButton.SetFarbe(FB: TColor);
begin
 FFarbe := FB;
 paint;
end;

//====================================================================================================

procedure TFlatButton.SetText(T: string);

begin
   FText := T;
   paint;
end;


//====================================================================================================

procedure TFlatButton.SetTextLeft(TL: integer);

begin
   FTextLeft := TL;
   paint;
end;


//====================================================================================================

procedure TFlatButton.SetTextTop(TT: integer);

begin
   FTextTop := TT;
   paint;
end;


//====================================================================================================

constructor TFlatButton.Create(AOwner: TComponent);

begin
   inherited Create(AOwner);
   width := 75;
   height := 25;
   FButtonState := stUp;
end;


//====================================================================================================

destructor TFlatButton.Destroy;

begin
   inherited Destroy;
end;


//====================================================================================================

procedure TFlatButton.paint;
begin
   h := height;
   w := width;

   case FButtonState of
      stUp   : paintUp;
      stDown : PaintDown;
   end;

   canvas.brush.style := bsClear;
   canvas.font.size := font.size;
   canvas.font.name := font.name;
   a := height div 2;
   zz := Canvas.textheight(FText);
   zz := zz div 2;
   o := a - zz;
   FTextTop := o;
   a := width div 2;
   zz := Canvas.textwidth(FText);
   zz := zz div 2;
   l := a - zz;
   FTextLeft := l;
   x := TextLeft;
   y := TextTop;
   canvas.textout(x, y, FText);

end;


//====================================================================================================

procedure TFlatButton.PaintDown;

begin
   h := height;
   w := width;
   canvas.Font.color := clRed;
   canvas.pen.color := clRed;
   canvas.Brush.Color := FFarbe;
   canvas.Rectangle(0, 0, w, h);
end;


//====================================================================================================

procedure TFlatButton.PaintUp;

begin
   h := height;
   w := width;
   canvas.Font.color := Font.color;
   canvas.pen.color := FRandFarbe;
   canvas.Brush.Color := FFarbe;
   canvas.Rectangle(0, 0, w, h);
end;


//====================================================================================================


procedure TFlatButton.SetButtonState(BS: TButtonState);

begin
   FButtonState := BS;
   paint;
end;


//====================================================================================================


procedure TFlatButton.MouseDown(Button: TMouseButton; Shift: TShiftState; X, Y: Integer);

begin
   inherited MouseDown(Button, Shift, x, y);
   ButtonState := stDown;
   paint;
end;



//====================================================================================================

procedure TFlatButton.MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer);


begin
   inherited MouseUp(Button, Shift, x, y);
   ButtonState := stUp;
   paint;
end;


//====================================================================================================

procedure Register;

begin
   RegisterComponents('AST', [TFlatButton]);
end;


//====================================================================================================

end.
